Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(527)

Unified Diff: runtime/vm/stub_code_ia32.cc

Issue 9963032: Minor cleanup in assembly code. (Closed) Base URL: http://dart.googlecode.com/svn/branches/bleeding_edge/dart/
Patch Set: Created 8 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « runtime/vm/code_generator_ia32.cc ('k') | no next file » | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: runtime/vm/stub_code_ia32.cc
===================================================================
--- runtime/vm/stub_code_ia32.cc (revision 6065)
+++ runtime/vm/stub_code_ia32.cc (working copy)
@@ -1759,9 +1759,10 @@
// Check if an instance class is a subtype of class/interface using simple
// superchain and interface array traversal. Does not take type parameters into
// account.
-// EAX: instance.
+// EAX: instance (preserved)
// EDX: class/interface to test against (is class of instance a subtype of it).
// Result in EDX: 1 is subtype, 0 maybe not.
// Destroys EBX, ECX.
void StubCode::GenerateIsRawSubTypeStub(Assembler* assembler) {
const Immediate raw_null =
@@ -1805,12 +1806,12 @@
__ jmp(&array_loop, Assembler::kNearJump);
__ Bind(&not_found);
- __ xorl(EAX, EAX);
+ __ xorl(EBX, EBX);
__ LeaveFrame();
__ ret();
__ Bind(&found);
- __ movl(EAX, Immediate(1));
+ __ movl(EBX, Immediate(1));
__ LeaveFrame();
__ ret();
« no previous file with comments | « runtime/vm/code_generator_ia32.cc ('k') | no next file » | no next file with comments »
@@ -1759,9 +1759,10 @@
// EDX: class/interface to test against (is class of instance a subtype of it).
-// Result in EDX: 1 is subtype, 0 maybe not.
+// (preserved).
+// Result in EBX: 1 is subtype, 0 maybe not.
// Destroys EBX, ECX.
void StubCode::GenerateIsRawSubTypeStub(Assembler* assembler) {

Powered by Google App Engine
This is Rietveld 408576698